package org.tbasket.test.pages

import zio.test.ZIOSpecDefault
import org.tbasket.endpoint.Endpoint.handle
import org.tbasket.handler.HandlerUtils.parseAttribute
import org.tbasket.test.TestUtils
import org.tbasket.test.TestUtils.getJsonBody
import org.tbasket.test.pages.RegisterPageHandlerTests.test
import zio.http.*
import zio.http.model.{HeaderNames, Headers, Status}
import zio.json.ast.JsonCursor
import zio.test.Assertion.*
import zio.test.*

object RegisterPageHandlerTests extends TBasketPageSpec("/register") {
  
  
  private def requestsSpec = suite("bad request tests")(
  
  )
  
  private def registerSpec = suite("register tests")(
    test("normal register") {
      for
        resp <- handle(Request.post(Body.fromString(s"""{"name":"tuaillon","forename":"leo","email":"leo.tuaillon@etu.uca.fr","password":"bouhours"}"""), url))
      
      yield
        assert(resp)(hasField("status", _.status, equalTo(Status.Found)))
          && assert(resp)(hasField("body", _.body, equalTo(Body.empty))) //TODO assert that the cookie name is JWT
          && assert(resp)(hasField("headers", _.headers, exists(hasField("key", _.key, equalTo(HeaderNames.setCookie)))))
          && assert(resp)(hasField("headers", _.headers, contains(Headers.location("/"))))
    },
    test("register again with same credentials") {
      for
        resp <- handle(Request.post(Body.fromString(s"""{"name":"tuaillon","forename":"leo","email":"leo.tuaillon@etu.uca.fr","password":"bouhours"}"""), url))
        json <- getJsonBody(resp)
        errorType <- parseAttribute(json, "error", JsonCursor.field("error").isString)
        
      yield
        assert(resp)(hasField("status", _.status, equalTo(Status.NotAcceptable)))
          && assert(errorType)(equalTo("already registered"))
          && assert(resp)(hasField("headers", _.headers, contains(Headers.location("/login"))))
    }
  )
  
  override def tspec = suite("/login page handler")(
    requestsSpec,
    registerSpec
  )
}
